marktools.detach_stem_tremolos_attached_to_component
====================================================

.. autofunction:: abjad.tools.marktools.detach_stem_tremolos_attached_to_component.detach_stem_tremolos_attached_to_component
